@@ -1,6 +1,6 @@
 package Catalyst::Plugin::AutoCRUD::Controller::Root;
 BEGIN {
-  $Catalyst::Plugin::AutoCRUD::Controller::Root::VERSION = '1.112560';
+  $Catalyst::Plugin::AutoCRUD::Controller::Root::VERSION = '1.112770';
 }
 
 use strict;
@@ -115,7 +115,9 @@ sub do_meta : Private {
     $c->forward('build_site_config');
 
     # ACLs on the schema and source from site config
-    if ($c->stash->{site_conf}->{$db}->{hidden} eq 'yes') {
+    if ($c->stash->{site_conf}->{$db}->{hidden}
+        and $c->stash->{site_conf}->{$db}->{hidden} eq 'yes') {
+
         if ($site eq 'default') {
             $c->detach('verboden', [$c->uri_for( $self->action_for('no_db') )]);
         }
@@ -123,7 +125,9 @@ sub do_meta : Private {
             $c->detach('verboden', [$c->uri_for( $self->action_for('no_schema'), [$site] )]);
         }
     }
-    if ($c->stash->{site_conf}->{$db}->{$table}->{hidden} eq 'yes') {
+    if ($c->stash->{site_conf}->{$db}->{$table}->{hidden}
+        and $c->stash->{site_conf}->{$db}->{$table}->{hidden} eq 'yes') {
+
         if ($site eq 'default') {
             $c->detach('verboden', [$c->uri_for( $self->action_for('no_table'), [$db] )]);
         }
